Stan Math Library: stan/math/prim/mat/fun/resize.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
resize.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
void | stan::math::resize (T &x, std::vector< size_t > dims)
| Recursively resize the specified vector of vectors, which must bottom out at scalar values, Eigen vectors or Eigen matrices. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.